@@ -22,11 +22,11 @@ PyMODINIT_FUNC PyInit_k1a(void) {
     m = PyModule_Create(&k1a::k1amodule);
     if (m == NULL) return NULL;
 
-    std::string version = "1.0.6";
+    std::string version = "1.0.9";
     PyModule_AddObject(m, "__version__", PyUnicode_FromString(version.c_str()));
 
     Py_INCREF(&k1a::PyStrIterCat_Type);
-    PyModule_AddObject(m, "str_iter", (PyObject *)&k1a::PyStrIterCat_Type);
+    PyModule_AddObject(m, "StrIterCat", (PyObject *)&k1a::PyStrIterCat_Type);
 
     if (k1a::debug) k1a::log_println("module finish init");
     return m;
